@@ -61,10 +61,19 @@ MailClient::~MailClient()
 {
 }
 
-bool MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, bool bccMe, const QString &attachment, const QString &mailTransport)
+QString const MailClient::errorMsg()
+{
+    return errorString;
+}
+
+bool MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                               const KIdentityManagement::Identity &identity, bool bccMe,
+                               const QString &attachment,
+                               const QString &mailTransport)
 {
     const KCalendarCore::Attendee::List attendees = incidence->attendees();
     if (attendees.isEmpty()) {
+        errorString = i18n("No attendees specified");
         qCWarning(KOALARMCLIENT_LOG) << "There are no attendees to e-mail";
         return false;
     }
@@ -106,6 +115,7 @@ bool MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
     if (toList.isEmpty() && ccList.isEmpty()) {
         // Not really to be called a groupware meeting, eh
         qCDebug(KOALARMCLIENT_LOG) << "There are really no attendees to e-mail";
+        errorString = i18n("No attendees specified");
         return false;
     }
     QString to;
@@ -132,7 +142,11 @@ bool MailClient::mailAttendees(const KCalendarCore::IncidenceBase::Ptr &incidenc
                 bccMe, attachment, mailTransport);
 }
 
-bool MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &attachment, const QString &sub, const QString &mailTransport)
+bool MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                               const KIdentityManagement::Identity &identity,
+                               const QString &from, bool bccMe,
+                               const QString &attachment, const QString &sub,
+                               const QString &mailTransport)
 {
     const QString to = incidence->organizer().fullName();
     QString subject = sub;
@@ -152,7 +166,11 @@ bool MailClient::mailOrganizer(const KCalendarCore::IncidenceBase::Ptr &incidenc
                 bccMe, attachment, mailTransport);
 }
 
-bool MailClient::mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence, const KIdentityManagement::Identity &identity, const QString &from, bool bccMe, const QString &recipients, const QString &attachment, const QString &mailTransport)
+bool MailClient::mailTo(const KCalendarCore::IncidenceBase::Ptr &incidence,
+                        const KIdentityManagement::Identity &identity,
+                        const QString &from, bool bccMe,
+                        const QString &recipients, const QString &attachment,
+                        const QString &mailTransport)
 {
     QString subject;
 
@@ -175,19 +193,25 @@ QStringList extractEmailAndNormalize(const QString &email)
     QStringList normalizedEmail;
     normalizedEmail.reserve(splittedEmail.count());
     for (const QString &email : splittedEmail) {
-        const QString str = KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(
-                                                                   email));
+        const QString str =
+            KEmailAddress::extractEmailAddress(KEmailAddress::normalizeAddressesAndEncodeIdn(email));
         normalizedEmail << str;
     }
     return normalizedEmail;
 }
 
-bool MailClient::send(const KIdentityManagement::Identity &identity, const QString &from, const QString &_to, const QString &cc, const QString &subject, const QString &body, bool hidden, bool bccMe, const QString &attachment, const QString &mailTransport)
+bool MailClient::send(const KIdentityManagement::Identity &identity,
+                      const QString &from, const QString &_to, const QString &cc,
+                      const QString &subject, const QString &body,
+                      bool hidden, bool bccMe,
+                      const QString &attachment,
+                      const QString &mailTransport)
 {
     Q_UNUSED(hidden);
 
     if (!MailTransport::TransportManager::self()->showTransportCreationDialog(
             nullptr, MailTransport::TransportManager::IfNoTransportExists)) {
+        errorString = i18n("Unable to start the transport manager");
         return false;
     }
 
@@ -222,6 +246,7 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
                                       << mailTransport
                                       << MailTransport::TransportManager::self()->
             defaultTransportName();
+        errorString = i18n("Unable to determine a mail transport");
         return false;
     }
 
@@ -357,6 +382,7 @@ bool MailClient::send(const KIdentityManagement::Identity &identity, const QStri
     qjob->setMessage(message);
     if (!qjob->exec()) {
         qCDebug(KOALARMCLIENT_LOG) << "Error queuing message in outbox:" << qjob->errorText();
+        errorString = i18n("Unable to queue the message in the outbox");
         return false;
     }
 
