@@ -854,18 +854,30 @@ void CalendarView::edit_paste()
         endDT = agendaView->selectionEnd();
         useEndTime = !agendaView->selectedIsSingleCell();
         if (agendaView->selectedIsAllDay()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             finalDateTime = QDateTime(date);
+#else
+            finalDateTime = QDateTime(date.startOfDay());
+#endif
         } else {
             finalDateTime = QDateTime(date, agendaView->selectionStart().time());
         }
     } else if (curView == monthView && monthView->selectionStart().isValid()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         finalDateTime = QDateTime(monthView->selectionStart().date());
+#else
+        finalDateTime = QDateTime(monthView->selectionStart().date().startOfDay());
+#endif
         pasteFlags = KCalUtils::DndFactory::FlagPasteAtOriginalTime;
     } else if (!mDateNavigator->selectedDates().isEmpty() && curView->supportsDateNavigation()) {
         // default to the selected date from the navigator
         const KCalendarCore::DateList dates = mDateNavigator->selectedDates();
         if (!dates.isEmpty()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             finalDateTime = QDateTime(dates.first());
+#else
+            finalDateTime = QDateTime(dates.first().startOfDay());
+#endif
             pasteFlags = KCalUtils::DndFactory::FlagPasteAtOriginalTime;
         }
     }
@@ -1166,7 +1178,11 @@ void CalendarView::newJournal(const QString &text, const QDate &date)
         = IncidenceEditorNG::IncidenceDefaults::minimalIncidenceDefaults();
 
     KCalendarCore::Journal::Ptr journal(new KCalendarCore::Journal);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     defaults.setStartDateTime(QDateTime(date));
+#else
+    defaults.setStartDateTime(QDateTime(date.startOfDay()));
+#endif
     defaults.setDefaults(journal);
 
     journal->setSummary(text);
@@ -2638,17 +2654,7 @@ Akonadi::Collection CalendarView::defaultCollection(const QLatin1String &mimeTyp
         return collection;
     }
 
-    // 3. Try last selected folder
-    collection
-        = mCalendar->collection(IncidenceEditorNG::IncidenceEditorSettings::self()->lastSelectedFolder());
-    supportsMimeType
-        = collection.contentMimeTypes().contains(mimeType) || mimeType == QLatin1String("");
-    hasRights = collection.rights() & Akonadi::Collection::CanCreateItem;
-    if (collection.isValid() && supportsMimeType && hasRights) {
-        return collection;
-    }
-
-    // 4. Try the selected collection
+    // 3. Try the selected collection
     collection = selectedCollection();
     supportsMimeType
         = collection.contentMimeTypes().contains(mimeType) || mimeType == QLatin1String("");
@@ -2657,7 +2663,7 @@ Akonadi::Collection CalendarView::defaultCollection(const QLatin1String &mimeTyp
         return collection;
     }
 
-    // 5. Try the checked collections
+    // 4. Try the checked collections
     const Akonadi::Collection::List collections = checkedCollections();
     for (const Akonadi::Collection &checkedCollection : collections) {
         supportsMimeType
